@@ -1,7 +1,5 @@
 package Catalyst::View::ByCode::Renderer;
-{
-  $Catalyst::View::ByCode::Renderer::VERSION = '0.24';
-}
+$Catalyst::View::ByCode::Renderer::VERSION = '0.25';
 use strict;
 use warnings;
 use base qw(Exporter);
@@ -257,7 +255,9 @@ sub _render {
                                 my $k = $_;
                                 my $v = $attr->{$k};
 
-                                if ($k eq 'autofocus'      ||
+                                if (!defined $v) {
+                                    " $k";
+                                } elsif ($k eq 'autofocus'      ||
                                     $k eq 'checked'        ||
                                     $k eq 'disabled'       ||
                                     $k eq 'formnovalidate' ||
@@ -524,8 +524,11 @@ sub _yield {
 # get/set attribute(s) of latest open tag
 #
 sub attr {
-    return $top[-1]->[1]->{$_[0]} if (scalar(@_) == 1);
+    # FIXME: better discovery of set/get !defined wantarray (?)
+    
+    return $top[-1]->[1]->{$_[0]} if scalar @_ == 1 && defined wantarray;
 
+    no warnings; # avoid odd no of elements in hash
     %{ $top[-1]->[1] } = ( %{ $top[-1]->[1] }, @_ );
     return;
 }
